@@ -1,5 +1,4 @@
 # SNMP::Info::CDP
-# $Id$
 #
 # Changes since Version 0.7 Copyright (c) 2004 Max Baker
 # All rights reserved.
@@ -34,16 +33,17 @@
 package SNMP::Info::CDP;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::CDP::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::CDP::EXPORT_OK = qw//;
 
-use vars
-    qw/$VERSION $DEBUG %FUNCS %GLOBALS %MIBS %MUNGE $INIT %CDP_CAPABILITIES/;
+our
+    ($VERSION, $DEBUG, %FUNCS, %GLOBALS, %MIBS, %MUNGE, $INIT, %CDP_CAPABILITIES);
 
-$VERSION = '3.34';
+$VERSION = '3.95';
 
 # Five data structures required by SNMP::Info
 %MIBS = ( 'CISCO-CDP-MIB' => 'cdpGlobalRun' );
@@ -54,16 +54,15 @@ $VERSION = '3.34';
     'cdp_run'      => 'cdpGlobalRun',
     'cdp_interval' => 'cdpGlobalMessageInterval',
     'cdp_holdtime' => 'cdpGlobalHoldTime',
-    'cdp_gid'       => 'cdpGlobalDeviceId',
+    'cdp_gid'      => 'cdpGlobalDeviceId',
 );
 
 %FUNCS = (
-    'cdp_index'        => 'cdpCacheIfIndex',
     'cdp_proto'        => 'cdpCacheAddressType',
     'cdp_addr'         => 'cdpCacheAddress',
     'cdp_ver'          => 'cdpCacheVersion',
     'cdp_dev_id'       => 'cdpCacheDeviceId',
-    'cdp_port'         => 'cdpCacheDevicePort',
+    'cdp_dev_port'     => 'cdpCacheDevicePort',
     'cdp_platform'     => 'cdpCachePlatform',
     'cdp_capabilities' => 'cdpCacheCapabilities',
     'cdp_domain'       => 'cdpCacheVTPMgmtDomain',
@@ -80,11 +79,9 @@ $VERSION = '3.34';
     'cdp_capabilities' => \&SNMP::Info::munge_bits,
     'cdp_platform'     => \&SNMP::Info::munge_null,
     'cdp_domain'       => \&SNMP::Info::munge_null,
-    'cdp_port'         => \&SNMP::Info::munge_null,
     'cdp_ver'          => \&SNMP::Info::munge_null,
     'cdp_ip'           => \&SNMP::Info::munge_ip,
     'cdp_power'        => \&munge_power,
-
 );
 
 %CDP_CAPABILITIES = (
@@ -111,28 +108,21 @@ sub munge_power {
 sub hasCDP {
     my $cdp = shift;
 
-    my $ver = $cdp->{_version};
+    # Check the global that is supposed to indicate CDP is running
+    my $cdp_run = $cdp->cdp_run();
+    return 1 if $cdp_run;
 
-    # SNMP v1 clients dont have the globals
-    if ( defined $ver and $ver == 1 ) {
-        my $cdp_ip = $cdp->cdp_ip();
+    # SNMP v1 clients don't have the globals, fallback
+    # by checking if it would report neighbors
+    my $cdp_ip = $cdp->cdp_ip() || {};
+    return 1 if scalar keys %$cdp_ip;
 
-        # See if anything in cdp cache, if so we have cdp
-        return 1 if ( defined $cdp_ip and scalar( keys %$cdp_ip ) );
-        return;
-    }
-
-    return $cdp->cdp_run();
+    return;
 }
 
 sub cdp_if {
     my $cdp = shift;
 
-    # See if by some miracle Cisco implemented the cdpCacheIfIndex entry
-    my $cdp_index = $cdp->cdp_index();
-    return $cdp_index if defined $cdp_index;
-
-    # Nope, didn't think so. Now we fake it.
     my $cdp_ip = $cdp->cdp_ip();
     unless ( defined $cdp_ip ) {
         $cdp->error_throw(
@@ -225,6 +215,28 @@ sub cdp_id {
     return \%cdp_id;
 }
 
+sub cdp_port {
+    my $cdp    = shift;
+    my $partial = shift;
+
+    my $ch = $cdp->cdp_dev_port($partial) || {};
+
+    # most devices return a string with the interface name here (Port-ID TLV)
+    # see https://www.cisco.com/c/en/us/td/docs/ios-xml/ios/cdp/command/cdp-cr-book/cdp-cr-a1.html
+    # it seems however that some devices report hex encoded mac addresses for this, see
+    # https://github.com/netdisco/snmp-info/issues/252
+    # once these bad devices get known we can figure out workarounds for them
+
+    my %cdp_port;
+    foreach my $key ( sort keys %$ch ) {
+        my $port = $ch->{$key};
+        next unless $port;
+        $port = SNMP::Info::munge_null($port);
+        $cdp_port{$key} = $port;
+    }
+    return \%cdp_port;
+}
+
 1;
 __END__
 
@@ -238,10 +250,10 @@ Max Baker
 
 =head1 SYNOPSIS
 
- my $cdp = new SNMP::Info ( 
+ my $cdp = new SNMP::Info (
                              AutoSpecify => 1,
                              Debug       => 1,
-                             DestHost    => 'router', 
+                             DestHost    => 'router',
                              Community   => 'public',
                              Version     => 2
                            );
@@ -252,7 +264,7 @@ Max Baker
  $hascdp   = $cdp->hasCDP() ? 'yes' : 'no';
 
  # Print out a map of device ports with CDP neighbors:
- my $interfaces = $cdp->interfaces();
+ my $interfaces   = $cdp->interfaces();
  my $cdp_if       = $cdp->cdp_if();
  my $cdp_ip       = $cdp->cdp_ip();
  my $cdp_port     = $cdp->cdp_port();
@@ -267,17 +279,17 @@ Max Baker
 
 =head1 DESCRIPTION
 
-SNMP::Info::CDP is a subclass of SNMP::Info that provides an object oriented 
+SNMP::Info::CDP is a subclass of SNMP::Info that provides an object oriented
 interface to CDP information through SNMP.
 
 CDP is a Layer 2 protocol that supplies topology information of devices that
-also speak CDP, mostly switches and routers.  CDP is implemented in Cisco and
-some HP devices.
+also speak CDP, mostly switches and routers.  CDP is implemented by Cisco and
+several other vendors.
 
 Create or use a device subclass that inherits this class.  Do not use
 directly.
 
-Each device implements a subset of the global and cache entries. 
+Each device implements a subset of the global and cache entries.
 Check the return value to see if that data is held by the device.
 
 =head2 Inherited Classes
@@ -292,9 +304,7 @@ None.
 
 =back
 
-MIBs can be found at ftp://ftp.cisco.com/pub/mibs/v2/v2.tar.gz
-
-=head1 GLOBAL METHODS
+=head1 GLOBALS
 
 These are methods that return scalar values from SNMP
 
@@ -302,7 +312,7 @@ These are methods that return scalar values from SNMP
 
 =item  $cdp->hasCDP()
 
-Is CDP is active in this device?  
+Is CDP is active in this device?
 
 Accounts for SNMP version 1 devices which may have CDP but not cdp_run()
 
@@ -321,13 +331,13 @@ Interval in seconds at which CDP messages are generated.
 
 =item $cdp->cdp_holdtime()
 
-Time in seconds that CDP messages are kept. 
+Time in seconds that CDP messages are kept.
 
 (C<cdpGlobalHoldTime>)
 
-=item  $cdp->cdp_gid() 
+=item  $cdp->cdp_gid()
 
-Returns CDP device ID.  
+Returns CDP device ID.
 
 This is the device id broadcast via CDP to other devices, and is what is
 retrieved from remote devices with $cdp->id().
@@ -348,9 +358,9 @@ to a hash.
 =item $cdp->cdp_capabilities()
 
 Returns Device Functional Capabilities.  Results are munged into an ascii
-binary string, MSB.  Each digit represents a bit from the table below from 
+binary string, MSB.  Each digit represents a bit from the table below from
 the CDP Capabilities Mapping to Smartport Type table within the
-Cisco Small Business 200 Series Smart Switch Administration Guide, 
+Cisco Small Business 200 Series Smart Switch Administration Guide,
 L<http://www.cisco.com/c/en/us/support/switches/small-business-200-series-smart-switches/products-maintenance-guides-list.html>:
 
 (Bit) - Description
@@ -400,7 +410,7 @@ C<CISCO-VTP-MIB::managementDomainName>
 
 (C<cdpCacheVTPMgmtDomain>)
 
-=item $cdp->cdp_duplex() 
+=item $cdp->cdp_duplex()
 
 Returns the port duplex status from remote devices.
 
@@ -417,7 +427,7 @@ Returns remote device id string
 Returns the mapping to the SNMP Interface Table.
 
 Note that a lot devices don't implement $cdp->cdp_index(),  So if it isn't
-around, we fake it. 
+around, we fake it.
 
 In order to map the cdp table entry back to the interfaces() entry, we
 truncate the last number off of it :
@@ -428,7 +438,7 @@ truncate the last number off of it :
 
   # if not, let's fake it
   my $cdp_ip       = $device->cdp_ip();
-    
+
   my %cdp_if
   foreach my $key (keys %$cdp_ip){
       $iid = $key;
@@ -436,13 +446,13 @@ truncate the last number off of it :
       $iid =~ s/\.\d+$//;
       $cdp_if{$key} = $iid;
   }
- 
+
   return \%cdp_if;
 
 
 =item $cdp->cdp_index()
 
-Returns the mapping to the SNMP2 Interface table for CDP Cache Entries. 
+Returns the mapping to the SNMP2 Interface table for CDP Cache Entries.
 
 Most devices don't implement this, so you probably want to use $cdp->cdp_if()
 instead.
@@ -464,17 +474,18 @@ Returns remote address
 
 (C<cdpCacheAddress>)
 
-=item $cdp->cdp_platform() 
+=item $cdp->cdp_platform()
 
-Returns remote platform id 
+Returns remote platform id
 
 (C<cdpCachePlatform>)
 
 =item $cdp->cdp_port()
 
-Returns remote port ID
+Returns remote Port-ID. Most of the time this is a string with the port name, but this
+is not guaranteed to be so.
 
-(C<cdpDevicePort>)
+(C<cdpCacheDevicePort>)
 
 =item  $cdp->cdp_proto()
 
@@ -482,7 +493,7 @@ Returns remote address type received.  Usually IP.
 
 (C<cdpCacheAddressType>)
 
-=item $cdp->cdp_ver() 
+=item $cdp->cdp_ver()
 
 Returns remote hardware version
 
@@ -501,7 +512,7 @@ for decimal placement.
 
 (C<cdpCachePowerConsumption>)
 
-=item  $cdp->cdp_cap() 
+=item  $cdp->cdp_cap()
 
 Returns hash of arrays with each array containing the system capabilities
 supported by the remote system.  Possible elements in the array are
